@@ -1,19 +1,17 @@
 import sys
 
 
-__all__ = ['text_type', 'string_types', 'iteritems', 'itervalues', 'izip']
+__all__ = ['string_types', 'iteritems', 'itervalues', 'izip']
 
 
 if sys.version_info[0] >= 3:
-    text_type = str
     string_types = str,
     iteritems = lambda o: o.items()
     itervalues = lambda o: o.values()
     izip = zip
 
 else:
-    text_type = unicode
-    string_types = basestring,
+    string_types = str, unicode
     iteritems = lambda o: o.iteritems()
     itervalues = lambda o: o.itervalues()
     from itertools import izip
